####  oscars.py ####

import csv


def read_csv_table(csv_filename) :
    all_rows = []
    with open(csv_filename, "r") as csv_file :
        reader = csv.reader(csv_file)
        for row in reader:
            all_rows += [row]
    return all_rows


def is_prefix(pre, word) :
    """
    Returns True if pre is a prefix of word
    """
    # pre is a prefix of word if it is equal to the first len(pre)
    # characters of word
    return pre == word[:len(pre)]


def count_nominations(movie, nomination_list):
    '''Function that takes two arguments:  movie (str) and 
    nomination_list (list of lists) and returns the count (int)
    of the number of times movie is nominated.'''

    # initialize accumulation variable 
    count = 0
    # iterate over category list of nominations
    for category in nomination_list:
        # iterate over list of nominations in a category
        for nominee in category:
            # is the movie name a prefix of nomination?
            if is_prefix(movie, nominee):
                count += 1

    return count


def most_nominations(movie_list, nomination_list):
    most_so_far = 0
    most_list = []
    for movie in movie_list:
        num = count_nominations(movie, nomination_list)
        # found a movie with more nominations
        if num > most_so_far: 
            most_so_far = num
            #  remember the movie
            most_list = [movie]

        # what to do if there is a tie?
        elif num == most_so_far:

            # remember this movie as well
            most_list += [movie]
    return most_list



#### If name is main block:  Call functions here #####

if __name__ == "__main__":
    # calling csv reader helper function
    oscar_data = read_csv_table("oscars.csv")

    # extracting list of movies
    movies = oscar_data[0]

    # extracting the rest: list of list of strings (nominations)
    nominations = oscar_data[1:]

    print("Barbie got", count_nominations("Barbie", nominations), "nominations.")

    # the asterisk below says print all the contents of the list
    print("The movie(s) that got the most nominations:",\
            *most_nominations(movies, nominations)) 


